# IOTileBuild
A python package for building IOTile components.

## Installation

```
pip install iotile-build
```

## Copyright and license
This code is adapted from code and documentation copyright 2015 WellDone
International as pymomo. The IOTile package is released under the
[LGPLv3](https://www.gnu.org/licenses/lgpl.html) Open Source license.  See the
LICENSE file.

`iotile-build` redistributes SCons.  More information on SCons can be found at
http://scons.org